# Sage version information for shell scripts
# This file is auto-generated by the sage-update-version script, do not edit!
SAGE_VERSION='9.6.beta5'
SAGE_RELEASE_DATE='2022-03-12'
SAGE_VERSION_BANNER='SageMath version 9.6.beta5, Release Date: 2022-03-12'
